pub struct HtmlWriter<'a, 'b> { /* private fields */ }Expand description
A writer created by HtmlContext::writer that makes everything written
to it safe for its context before appending it to the underlying
Formatter.
The inherent methods mirror fmt::Write, which the writer also
implements for use with write!.
Implementations
Sourceimpl HtmlWriter<'_, '_>
impl HtmlWriter<'_, '_>
Sourcepub fn write_str(&mut self, s: &str)
pub fn write_str(&mut self, s: &str)
Writes s, escaped or validated for this writer’s context.
Panics
Panics in the ident contexts (AttributeKey,
ElementName) when s contains a
character that could break out of the identifier, since HTML has no
escape mechanism there.
Sourcepub fn write_char(&mut self, c: char)
pub fn write_char(&mut self, c: char)