AttributeKeyViewParts

Trait AttributeKeyViewParts 

pub trait AttributeKeyViewParts {
    // Required method
    fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>);
}
Converts a value used as an attribute key into view parts.

When this trait is implemented on a type, it can be used in the attribute key position of an element in the view! macro:

view! {
    <div (my_key)="value"></div>
}

Required Methods

fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)

Appends this attribute key to the view being built.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl AttributeKeyViewParts for &String

Source

fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)

Source

impl AttributeKeyViewParts for &str

Source

fn into_view_parts(self, _cx: &Cx, parts: &mut PartsWriter<'_>)

Source

impl AttributeKeyViewParts for String

Source

fn into_view_parts(self, _cx: &Cx, parts: &mut PartsWriter<'_>)

Source

impl<'b, T: ?Sized> AttributeKeyViewParts for &&'b T

Source

fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12> AttributeKeyViewParts for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12)

Source

fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> AttributeKeyViewParts for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)

Source

fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> AttributeKeyViewParts for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)

Source

fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9> AttributeKeyViewParts for (T1, T2, T3, T4, T5, T6, T7, T8, T9)

Source

fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8> AttributeKeyViewParts for (T1, T2, T3, T4, T5, T6, T7, T8)

Source

fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)

Source

impl<T1, T2, T3, T4, T5, T6, T7> AttributeKeyViewParts for (T1, T2, T3, T4, T5, T6, T7)

Source

fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)

Source

impl<T1, T2, T3, T4, T5, T6> AttributeKeyViewParts for (T1, T2, T3, T4, T5, T6)

Source

fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)

Source

impl<T1, T2, T3, T4, T5> AttributeKeyViewParts for (T1, T2, T3, T4, T5)

Source

fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)

Source

impl<T1, T2, T3, T4> AttributeKeyViewParts for (T1, T2, T3, T4)

Source

fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)

Source

impl<T1, T2, T3> AttributeKeyViewParts for (T1, T2, T3)

Source

fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)

Source

impl<T1, T2> AttributeKeyViewParts for (T1, T2)

Source

fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)

Source

impl<T1> AttributeKeyViewParts for (T1,)

Source

fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)

Implementors