IsSet

Trait IsSet 

pub trait IsSet { }
Implemented by typestate markers of properties that have been set.

build() on a generated builder requires every required property’s marker to implement this trait. Markers of unset properties are types named after the property, so the compile error names exactly which property is missing.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors