pub trait NodeViewParts {
// Required method
fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>);
}Expand description
Converts a value used in node position into view parts.
When this trait is implemented on a type, it can be used in the node position of an element
in the view! macro:
view! {
<div>(my_value)</div>
}Required Methods
Sourcefn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)
fn into_view_parts(self, cx: &Cx, parts: &mut PartsWriter<'_>)
Appends this value to the view being built.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".