Props

Trait Props 

pub trait Props {
    type Builder;

    // Required method
    fn builder() -> Self::Builder;
}
A props struct with a generated typestate builder.

Implemented by #[derive(Props)]. The derive also generates an inherent builder() function on the struct, so this trait only needs to be in scope when the builder is constructed generically.

Required Associated Types

type Builder

The builder type in its initial state, with no properties set.

Required Methods

fn builder() -> Self::Builder

Returns a builder with no properties set.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors